@@ -3,6 +3,8 @@ from libspn_keras.initializers.epsilon_inverse_fan_in import EpsilonInverseFanIn
 from libspn_keras.initializers.equidistant import Equidistant
 from libspn_keras.initializers.kmeans import KMeans
 from libspn_keras.initializers.poon_domingos import PoonDomingosMeanOfQuantileSplit
+from libspn_keras.initializers.poon_domingos import PoonDomingosStddevOfQuantileSplit
+
 
 __all__ = [
     "Dirichlet",
@@ -10,4 +12,5 @@ __all__ = [
     "Equidistant",
     "PoonDomingosMeanOfQuantileSplit",
     "KMeans",
+    "PoonDomingosStddevOfQuantileSplit",
 ]
