@@ -1,4 +1,5 @@
-from typing import Optional, Tuple
+from typing import Optional
+from typing import Tuple
 
 import tensorflow as tf
 from tensorflow import keras
@@ -21,7 +22,7 @@ from libspn_keras.constraints.greater_equal_epsilon_normalized import (
     GreaterEqualEpsilonNormalized,
 )
 from libspn_keras.logspace import logspace_wrapper_initializer
-from libspn_keras.sum_ops import SumOpBase
+from libspn_keras.sum_ops.base import SumOpBase
 
 
 class DenseSum(keras.layers.Layer):
@@ -34,10 +35,10 @@ class DenseSum(keras.layers.Layer):
     Args:
         num_sums: Number of sums per scope
         logspace_accumulators: If ``True``, accumulators will be represented in log-space which
-            is typically used with ``BackpropMode.GRADIENT``. If ``False``, accumulators will be
-            represented in linear space. Weights are computed by normalizing the accumulators
+            is typically used with :class:`~libspn_keras.SumOpGradBackprop`. If ``False``, accumulators
+            will be represented in linear space. Weights are computed by normalizing the accumulators
             per sum, so that we always end up with a normalized SPN. If ``None`` (default) it
-            will be set to ``True`` for ``BackpropMode.GRADIENT`` and ``False`` otherwise.
+            will be set to ``True`` for :class:`~libspn_keras.SumOpGradBackprop` and ``False`` otherwise.
         accumulator_initializer: Initializer for accumulator. Will automatically be converted
             to log-space values if ``logspace_accumulators`` is enabled.
         accumulator_regularizer: Regularizer for accumulator (experimental)
