@@ -16,7 +16,10 @@ class LogLikelihood(keras.metrics.Mean):
         super(LogLikelihood, self).__init__(name=name, **kwargs)
 
     def update_state(
-        self, _: tf.Tensor, y_pred: tf.Tensor, sample_weight: Optional[float] = None
+        self,
+        y_target: tf.Tensor,
+        y_pred: tf.Tensor,
+        sample_weight: Optional[float] = None,
     ) -> tf.Tensor:
         """
         Accumulates statistics for computing the reduction metric.
@@ -26,6 +29,7 @@ class LogLikelihood(keras.metrics.Mean):
         [1, 1, 0, 0] then value of `result()` would be 2.
 
         Args:
+            y_target: Target tensor, ignored since this metric is for unsupervised learning
             y_pred: Predictions coming from the model.
             sample_weight: Optional weighting of each example. Defaults to 1.
 
