@@ -1,4 +1,6 @@
-from typing import Dict, Tuple, Union
+from typing import Dict
+from typing import Tuple
+from typing import Union
 
 import tensorflow as tf
 from tensorflow import keras
@@ -7,9 +9,9 @@ from tensorflow.python.keras.engine import data_adapter
 
 class SumProductNetwork(keras.Model):
     """
-    An SPN analogue of tensorflow.keras.Model that can be trained generatively.
+    An SPN analogue of ``tensorflow.keras.Model`` that can be trained generatively.
 
-    It does not expect labels y when calling .fit() if ``unsupervised`` == True.
+    It does not expect labels y when calling ``.fit()`` if ``unsupervised == True``.
 
     Args:
         unsupervised (bool): If ``True`` (default) the model does not expect label inputs in
@@ -18,7 +20,7 @@ class SumProductNetwork(keras.Model):
     """
 
     def __init__(self, *args, unsupervised: bool = True, **kwargs):
-        super().__init__(*args, **kwargs)
+        super(SumProductNetwork, self).__init__(*args, **kwargs)
         self.unsupervised = unsupervised
 
     def _train_step_unsupervised(
